@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -217,7 +217,7 @@ class PredictionServiceAsyncClient:
         *,
         name: str = None,
         payload: data_items.ExamplePayload = None,
-        params: Sequence[prediction_service.PredictRequest.ParamsEntry] = None,
+        params: Mapping[str, str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -244,14 +244,13 @@ class PredictionServiceAsyncClient:
         -  Text Sentiment - TextSnippet, content up 500 characters,
            UTF-8 encoded.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1beta1
 
-            def sample_predict():
+            async def sample_predict():
                 # Create a client
-                client = automl_v1beta1.PredictionServiceClient()
+                client = automl_v1beta1.PredictionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 payload = automl_v1beta1.ExamplePayload()
@@ -263,7 +262,7 @@ class PredictionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.predict(request=request)
+                response = await client.predict(request=request)
 
                 # Handle the response
                 print(response)
@@ -288,7 +287,7 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (:class:`Sequence[google.cloud.automl_v1beta1.types.PredictRequest.ParamsEntry]`):
+            params (:class:`Mapping[str, str]`):
                 Additional domain-specific parameters, any string must
                 be up to 25000 characters long.
 
@@ -364,7 +363,12 @@ class PredictionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -376,7 +380,7 @@ class PredictionServiceAsyncClient:
         name: str = None,
         input_config: io.BatchPredictInputConfig = None,
         output_config: io.BatchPredictOutputConfig = None,
-        params: Sequence[prediction_service.BatchPredictRequest.ParamsEntry] = None,
+        params: Mapping[str, str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -399,14 +403,13 @@ class PredictionServiceAsyncClient:
         -  Video Object Tracking \* Text Extraction
         -  Tables
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1beta1
 
-            def sample_batch_predict():
+            async def sample_batch_predict():
                 # Create a client
-                client = automl_v1beta1.PredictionServiceClient()
+                client = automl_v1beta1.PredictionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = automl_v1beta1.BatchPredictRequest(
@@ -418,7 +421,7 @@ class PredictionServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -449,7 +452,7 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (:class:`Sequence[google.cloud.automl_v1beta1.types.BatchPredictRequest.ParamsEntry]`):
+            params (:class:`Mapping[str, str]`):
                 Required. Additional domain-specific parameters for the
                 predictions, any string must be up to 25000 characters
                 long.
@@ -592,7 +595,12 @@ class PredictionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -614,7 +622,9 @@ class PredictionServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-automl",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-automl",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
